An SVG text layout implementation on top of [usvg] crate.
Re-exports
Structs
- Fonts
Cache - Fonts cache. Contains resolved font files from the
fontdbdatabase. Have no capacity option because there is no sense in clearing fonts cache, at least for fframes If font is used within one frame there is a high chance it will be used at some future frame as well. - Usvgr
Text Layout Cache - Text layout cache. An lru cache strategy that holds an individual text node path group.
Traits
- Text
ToPath - A
usvgr::Textextension trait. - Tree
Text ToPath - A
usvgr::Treeextension trait.