pub trait TreeTextToPath {
    // Required methods
    fn convert_text(&mut self, fontdb: &Database, keep_named_groups: bool);
    fn convert_text_with_cache(
        &mut self,
        fontdb: &Database,
        cache: &mut UsvgrTextLayoutCache,
        fonts_cache: &mut FontsCache,
        keep_named_groups: bool
    );
}
A usvgr::Tree extension trait.

Required Methods

source

fn convert_text(&mut self, fontdb: &Database, keep_named_groups: bool)

Converts text nodes into paths.

We have not pass Options::keep_named_groups again, since this method affects the tree structure.

source

fn convert_text_with_cache( &mut self, fontdb: &Database, cache: &mut UsvgrTextLayoutCache, fonts_cache: &mut FontsCache, keep_named_groups: bool )

Converts text nodes into paths involving cache for every individual text node.

Implementations on Foreign Types

source

impl TreeTextToPath for Tree

source

fn convert_text(&mut self, fontdb: &Database, keep_named_groups: bool)

source

fn convert_text_with_cache( &mut self, fontdb: &Database, text_layouts_cache: &mut UsvgrTextLayoutCache, fonts_cache: &mut FontsCache, keep_named_groups: bool )

Implementors