pub struct FontsCache(/* private fields */);
Fonts cache. Contains resolved font files from the fontdb database. Have no capacity option because there is no sense in clearing fonts cache, at least for fframes If font is used within one frame there is a high chance it will be used at some future frame as well.

Implementations

source

impl FontsCache

source

pub fn new() -> Self

Creates a new empty cache.